The highest tagged major version is
v2.
package
module
Version:
v0.3.0
Opens a new window with list of versions in this module.
Published: Jan 23, 2021
License: BSD-3-Clause
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Generator struct {
Epoch time.Time
}
Generator holds info needed for generating custom snowflakes
NewGen returns a new generator
Parse parses the given snowflake into a timestamp
Snowflake is an ID generated by a Generator
Int returns the integer version of a snowflake
ToTime converts the snowflake to a timestamp
Source Files
¶
Click to show internal directories.
Click to hide internal directories.